OverlayPopup constructor

const OverlayPopup({
  1. Key? key,
  2. required Widget child,
  3. required Widget content(
    1. VoidCallback
    ),
  4. Color? backgroundColor,
  5. int? horizontalPadding,
  6. int? verticalPadding,
  7. VoidCallback? onOpened,
  8. bool blurBackground = false,
  9. double? blurOpacity,
})

Creates an OverlayPopup widget.

child is required and acts as the widget that triggers the popup. content is a required function that provides the content for the popup. Optional parameters include backgroundColor, horizontalPadding, verticalPadding, onOpened, blurBackground, and blurOpacity.

Implementation

const OverlayPopup({
  super.key,
  required this.child,
  required this.content,
  this.backgroundColor,
  this.horizontalPadding,
  this.verticalPadding,
  this.onOpened,
  this.blurBackground = false,
  this.blurOpacity,
});