content property

Widget Function(VoidCallback ) content
final

A function that returns the content to be displayed inside the popup. The content receives a callback function that can be used to close the popup.

Implementation

final Widget Function(VoidCallback) content;