horizontalPadding property
Optional padding on the horizontal axis, used for adjusting the position of the popup.
Implementation
final int? horizontalPadding;
Optional padding on the horizontal axis, used for adjusting the position of the popup.
final int? horizontalPadding;