verticalPadding property
Optional padding on the vertical axis, used for adjusting the position of the popup.
Implementation
final int? verticalPadding;
Optional padding on the vertical axis, used for adjusting the position of the popup.
final int? verticalPadding;