OverlayPopup constructor
const
OverlayPopup({})
Creates an OverlayPopup widget.
child is required and acts as the widget that triggers the popup.
content is a required function that provides the content for the popup.
Optional parameters include backgroundColor, horizontalPadding, verticalPadding,
onOpened, blurBackground, and blurOpacity.
Implementation
const OverlayPopup({
super.key,
required this.child,
required this.content,
this.backgroundColor,
this.horizontalPadding,
this.verticalPadding,
this.onOpened,
this.blurBackground = false,
this.blurOpacity,
});